#!/bin/bash

#---( Zenwalk Build Script
#---( Build Script written for OpenCOBOL
#---( Home Page: http://www.opencobol.org/
#---( Source: http://www.opencobol.org/modules/mydownloads
#---( Author: R S Ananda Murthy (rsamurti@airtelbroadband.in)
#---( Date build script was last modified: Tuesday, 04-Mar-2008.


#------------------( Set Package Name & Version )


soft='open-cobol'
softversion='1.1'
packageversion='54.1'


#------------------( Check for source file )


if [ -f $soft-$softversion.tar.gz  ]; then
   echo "Source file .. ok"
else
   echo "Source file does not exit. Download it first from the location"
   echo "http://www.opencobol.org/modules/mydownloads."
   exit
fi


#------------------( Set Package CPU Architecture Optimizations )


arch='i486'
cpu='i686'


#------------------( Set Build Location Variables )


buildir=$(pwd)
srcpkg="$buildir/$soft-$softversion.tar.gz"
src="$buildir/$soft-$softversion"
package="$soft-$softversion-$arch-$packageversion"
dest="$buildir/$package"


#------------------( Clean, prepare the work area and extract the source code )


cd $buildir
rm -rf $src
tar -xvf $srcpkg
rm -f $dest.tgz
rm -rf $dest
mkdir -p $dest


#------------------( Set Build Ownerships and CFLAGS, CXXFLAGS and FFLAGS )


chown -R root:root .
export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"
export FFLAGS="-O2 -march=i486 -mtune=i686"


#------------------( Configure, Make And Install The Software )


cd $src

./configure --prefix=/usr \
--bindir=/usr/bin \
--mandir=/usr/man \
--infodir=/usr/info
make
make check
make install DESTDIR=$dest


#------------------( Strip Executables (Comment out these lines if debugging info is needed) )


( cd $dest
  find . | xargs file | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded
)



#------------------( Compress Info Pages and Move To Correct Location )


( cd $dest/usr/info
  find . -name "*.info" | xargs gzip -9
  find . -name "*.info-?" | xargs gzip -9
  rm -f dir
)


#------------------( Move Documentation To Correct Location )


mkdir -p $dest/usr/doc/$soft-$softversion

cp -a \
  ABOUT-NLS AUTHORS COPYING COPYING.DOC COPYING.LIB ChangeLog INSTALL NEWS README THANKS TODO \
  $dest/usr/doc/$soft-$softversion



#------------------( Copy Build Script for Future Use )


mkdir -p $dest/usr/src/$soft-$softversion
cp $buildir/build-$soft.sh $dest/usr/src/$soft-$softversion/build-$soft.sh


#------------------( Create The Slackdesc )


mkdir -p $dest/install
cat <<EOF > $dest/install/slack-desc
          |-----handy-ruler------------------------------------------------------|
open-cobol: OpenCOBOL (An open-source COBOL compiler)
open-cobol: 
open-cobol: OpenCOBOL is an open-source COBOL compiler, which translates COBOL
open-cobol: programs to C code and compiles it using GCC.
open-cobol: 
open-cobol: 
open-cobol: 
open-cobol: 
open-cobol: 
open-cobol: 
open-cobol: 
EOF

#------------------( Create The doinst.sh )


cat <<EOF > $dest/install/doinst.sh
## This installs info directory informtation for the package.
if [ -x usr/bin/install-info ]
then
   usr/bin/install-info --info-dir=/usr/info usr/info/open-cobol.info.gz 2>/dev/null
fi
ldconfig
EOF


#------------------( Compress The Package And Clean Up The Work Area )


cd $dest

find . -perm 640 -exec chmod 644 {} \;
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

makepkg -l y -c n $package.tgz
mv $package.tgz ../$package.tgz
rm -rf $src
rm -rf $dest


#------------------( Generate the MD5 Check Sum )


cd $buildir
md5sum $package.tgz > $package.md5
zen-pkgcheck.pl $package.tgz
requiredbuilder -z $package.tgz > $package.dep
